@@ -30,6 +30,16 @@ test_that("basic regression and prediction", {
   expect_equal( yhat, rowMeans(yall), tolerance=1e-5)
 })
 
+test_that("selectTree works with regression", {  
+  et    <- extraTrees(train$x, train$y, nodesize=1, mtry=2, numRandomCuts=2, ntree=20)
+  trees <- rep(c(T, F), 10)
+  et10 <- selectTrees(et, trees )
+  expect_equal( et10$ntree, 10 )
+  yall   <- predict(et,   test$x, allValues=T)
+  yall10 <- predict(et10, test$x, allValues=T)
+  expect_equal( yall[,trees], yall10, tolerance=1e-5)
+})
+
 test_that("integer y is used as double for regression", {  
   et   <- extraTrees(train$x, as.integer(train$y), ntree=50)
   yhat <- predict(et, train$x)
